program RegLaz;

{$mode objfpc}{$H+}

uses
  Interfaces, // this includes the LCL widgetset
  Forms, SysUtils, Registry, Windows, ShlObj,
  Unit1, PPDK_RegFileType in '..\..\..\UNITS\PPDK_RegFileType.pas';

{$R *.res}

ResourceString
  cID_ERROR = 'Error:';
  cID_HELP  = 'Help:';
  cID_WARN  = 'Warning:';
  cID_INFO  = 'Information:';
  cHelpMsg  = 'Command line parameters:' + #13 +
  					  '-c<ext> or -c<.ext>' + #13 +
              'Checks for assocciation of Lazarus with the <ext> filetype.' + #13#13 +
              '-s<ext> or -s<.ext>' + #13 +
              'Assigns an assocciation of the <ext> filetype with Lazarus.' + #13#13 +
              '-u<ext> or -u<.ext>' + #13 +
              'Deletes an assocciation of the <ext> filetype with Lazarus.' + #13#13 +
              '-h' + #13 +
              'Displays this screen.';

procedure ShowMsg(sCaption, sText: String);
var
  nIcon: Integer;
begin
  nIcon := 0;
  case sCaption[1] of
    'E': nIcon := MB_ICONERROR;
    'H': nIcon := MB_ICONQUESTION;
    'I': nIcon := MB_ICONASTERISK;
    'W': nIcon := MB_ICONEXCLAMATION;
  end;
  Application.MessageBox(PChar(sText), PChar(sCaption), nIcon);
end;

var
  sOpt,
  sVal,
  srDESC,
  srLDESC,
  srMNUTXT,
  srCMD,
  srICON: String;
  nidx,
  nlen: Integer;
  Reg: TRegistry;
begin
  Application.Initialize;
  if(ParamCount > 0)then
  begin
    Reg := TRegistry.Create();
		if(FileExists('c:\lazarus\bin32\lazarus.exe'))then
		begin
	    bIDE32 := true;
	  end;
	  if(FileExists('c:\lazarus\bin64\lazarus.exe'))then
	  begin
	    bIDE64 := true;
	  end;
  	for nidx := 1 to ParamCount do
  	begin
      nlen := Length(ParamStr(nidx));
	    sOpt := LeftStr(ParamStr(nidx), 2);
	    sVal := RightStr(ParamStr(nidx), nlen - 2);
      if(nlen < 2)then
      begin
        ShowMsg(cID_ERROR, 'Invalid parameter: ' + sOpt);
      end
      else
      if(sVal = '')then
      begin
        if(sOpt = '-h')then
        begin
          ShowMsg(cID_HELP, cHelpMsg);
        end
        else
        begin
          ShowMsg(cID_WARN, 'Parameter #' + IntToStr(nidx) + ' (' + sOpt + ') has no value.');
        end;
      end
      else
      begin
        if(sOpt[2] in ['c','s','u'])then
        begin
          case sOpt[2] of
          	'c': { Check a file assocciation }
            begin
              if(GetFileExt(Reg, sVal))then
              begin
                ShowMsg(cID_INFO, 'Extension ''' + sVal + ''' is REGISTERED with Lazarus IDE.');
              end
              else
              begin
                ShowMsg(cID_WARN, 'Extension ''' + sVal + ''' is NOT registered with Lazarus IDE.');
              end;
            end;
            's': { Set a file assocciation }
            begin
              if(Pos('lpi', sVal) > 0)then
              begin
              	srDESC   := 'LazarusProject';
              	srLDESC  := 'Lazarus Project Information';
              	srICON   := 'c:\lazarus\images\LazarusProject.ico';
              end
              else
              if(Pos('lpr', sVal) > 0)then
              begin
              	srDESC   := 'LazarusProjectSource';
              	srLDESC  := 'Lazarus Project Main Source';
              	srICON   := 'c:\lazarus\images\lprfile.ico';
              end
              else
              if(Pos('lpk', sVal) > 0)then
              begin
              	srDESC   := 'LazarusPackage';
              	srLDESC  := 'Lazarus Package File';
              	srICON   := 'c:\lazarus\images\lazaruspackage.ico';
              end
              else
              if(Pos('lfm', sVal) > 0)then
              begin
              	srDESC   := 'LazarusForm';
              	srLDESC  := 'Lazarus Form File';
              	srICON   := 'c:\lazarus\images\LazarusForm.ico';
              end
              else
              if(Pos('pas', sVal) > 0)then
              begin
              	srDESC   := 'LazarusUnit';
              	srLDESC  := 'Object Pascal Unit';
              	srICON   := 'c:\lazarus\images\LazarusSource.ico';
              end
              else
              if(Pos('pp', sVal) > 0)then
              begin
              	srDESC   := 'LazarusFPCUnit';
              	srLDESC  := 'Object Pascal Unit';
              	srICON   := 'c:\lazarus\images\LazarusSource.ico';
              end
              else
              if(Pos('inc', sVal) > 0)then
              begin
              	srDESC   := 'LazarusInclude';
              	srLDESC  := 'Object Pascal Include File';
              	srICON   := 'c:\lazarus\images\includefile.ico';
              end;
              //
              if(not(bIDE32 or bIDE64))then
              begin
                ShowMsg(cID_ERROR, 'Code Typhon Lazarus binaries are not present!');
              end
              else
              begin
                if(bIDE32)then
                begin
              		{ set registration variables for x32}
            			srMNUTXT := 'Open with Lazarus (x32)';
									srCMD    := 'c:\lazarus\bin32\lazarus.exe "%1"';
                	SetFileExt(Reg, sVal, srDESC, srLDESC, srMNUTXT, 'open', srCMD, srICON, true);
                end;
                if(bIDE64)then
                begin
              		{ set registration variables for x64}
            			srMNUTXT := 'Open with Lazarus (x64)';
              		srCMD    := 'c:\lazarus\bin64\lazarus.exe "%1"';
              		SetFileExt(Reg, sVal, srDESC, srLDESC, srMNUTXT, 'open64', srCMD, srICON, false);
								end;
              	SHChangeNotify(SHCNE_ASSOCCHANGED, SHCNF_IDLIST, nil, nil);
	              ShowMsg(cID_INFO, 'Assocciation of ''' + sVal + ''' file type is succesful.');
              end;
            end;
            'u': { UnSet file accossiation }
            begin
              if((Pos('lpi', sVal) > 0) or
              	 (Pos('lpr', sVal) > 0) or
                 (Pos('lpk', sVal) > 0) or
                 (Pos('lfm', sVal) > 0) or
                 (Pos('pas', sVal) > 0) or
                 (Pos('pp', sVal) > 0)  or
                 (Pos('inc', sVal) > 0))then
              begin
                if(GetFileExt(Reg, sVal))then
                begin
              		if(UnSetFileExt(Reg, sVal))then
                	begin
	                  SHChangeNotify(SHCNE_ASSOCCHANGED, SHCNF_IDLIST, nil, nil);
	                  ShowMsg(cID_INFO, 'Disassocciation of ''' + sVal + ''' file type is succesful.');
	                end
	                else
	                begin
	                	ShowMsg(cID_ERROR, 'Disassocciation of ''' + sVal + ''' file type failed.');
	                end;
                end
                else
                begin
									ShowMsg(cID_WARN, 'Extension ''' + sVal + ''' is NOT registered with Lazarus IDE.' + #13 + 'Nothing to delete...');
                end;
              end;
            end;
          end;
        end
        else
        begin
					ShowMsg(cID_ERROR, 'Invalid parameter: ' + sOpt);
        end;
      end;
    end;
    FreeAndNil(Reg);
    Application.Terminate;
  end
  else
  begin
  	Application.CreateForm(TfrmMain, frmMain);
  	Application.Run;
  end;
  {
  Reg := TRegistry.Create();
  if(Application.HasOption('c',''))then
  begin
    sOpt := Application.GetOptionValue('c','');
    sOpt := LowerCase(sOpt);
    if(sOpt <> '')then
    begin
      //Register LPI
      if((sOpt = '.lpi') or (sOpt = 'lpi'))then
      begin
	      SetFileExt(Reg, '.lpi', 'LazarusProject', 'Lazarus Project Information', 'Open with Lazarus IDE', 'c:\lazarus\lazarus.exe "%1"', 'c:\lazarus\images\LazarusProject.ico');
      end;
      //Register LPR
      if((sOpt = '.lpr') or (sOpt = 'lpr'))then
      begin
	      SetFileExt(Reg, '.lpr', 'LazarusProjectSource', 'Lazarus Project Main Source', 'Open with Lazarus IDE', 'c:\lazarus\lazarus.exe "%1"', 'c:\lazarus\images\lprfile.ico');
      end;
      //Register LPK
      if((sOpt = '.lpk') or (sOpt = 'lpk'))then
      begin
	      SetFileExt(Reg, '.lpk', 'LazarusPackage', 'Lazarus Package File', 'Open with Lazarus IDE', 'c:\lazarus\lazarus.exe "%1"', 'c:\lazarus\images\lazaruspackage.ico');
      end;
      //Register LFM
      if((sOpt = '.lfm') or (sOpt = 'lfm'))then
      begin
	      SetFileExt(Reg, '.lfm', 'LazarusForm', 'Lazarus Form File', 'Open with Lazarus IDE', 'c:\lazarus\lazarus.exe "%1"', 'c:\lazarus\images\LazarusForm.ico');
      end;
      //Register PAS
      if((sOpt = '.pas') or (sOpt = 'pas'))then
      begin
	      SetFileExt(Reg, '.pas', 'LazarusUnit', 'Object Pascal Unit', 'Open with Lazarus IDE', 'c:\lazarus\lazarus.exe "%1"', 'c:\lazarus\images\LazarusSource.ico');
      end;
      //Register PP
      if((sOpt = '.pp') or (sOpt = 'pp'))then
      begin
	      SetFileExt(Reg, '.pp', 'LazarusFPCUnit', 'Object Pascal Unit', 'Open with Lazarus IDE', 'c:\lazarus\lazarus.exe "%1"', 'c:\lazarus\images\LazarusSource.ico');
      end;
      //Register INC
      if((sOpt = '.inc') or (sOpt = 'inc'))then
      begin
	      SetFileExt(Reg, '.inc', 'LazarusInclude', 'Object Pascal Include File', 'Open with Lazarus IDE', 'c:\lazarus\lazarus.exe "%1"', 'c:\lazarus\images\includefile.ico');
      end;
      SHChangeNotify(SHCNE_ASSOCCHANGED, SHCNF_IDLIST, nil, nil);
    end;
  end
  else
  begin
  end;
  }
end.

